# XIMG-EMBL project
This is the part of the project on Research and Development of X-ray tomography at the P14 EMBL beamline at PETRA-III, DESY

This package is dedicated to image processing, flatifield correction, phase retrieval and parallel-beam X-ray tomography.
There is no published manual yet so please contact me (Maxim Polikarpov, polikarpov.maxim@mail.ru) in case you would like to use this package and get some guidance. In addition, each function or class have a situational description.

Please check Jupyter notebooks above for examples.
